@@ -35,7 +35,7 @@ import unittest
 from textwrap import dedent
 from nose.tools import assert_equal, assert_almost_equal, raises
 
-from affine import Affine, EPSILON
+from affine import Affine, EPSILON, UndefinedRotationError
 
 
 def seq_almost_equal(t1, t2, error=0.00001):
@@ -517,6 +517,47 @@ def test_roundtrip():
     seq_almost_equal(point, roundtrip_point)
 
 
+def test_eccentricity():
+    assert_equal(Affine.identity().eccentricity, 0.0)
+    assert_equal(Affine.scale(2).eccentricity, 0.0)
+    #assert_equal(Affine.scale(0).eccentricity, ?)
+    assert_almost_equal(Affine.scale(2, 1).eccentricity, math.sqrt(3) / 2)
+    assert_almost_equal(Affine.scale(2, 3).eccentricity, math.sqrt(5) / 3)
+    assert_equal(Affine.scale(1, 0).eccentricity, 1.0)
+    assert_almost_equal(Affine.rotation(77).eccentricity, 0.0)
+    assert_almost_equal(Affine.translation(32, -47).eccentricity, 0.0)
+    assert_almost_equal(Affine.scale(-1, 1).eccentricity, 0.0)
+
+
+def test_eccentricity_complex():
+    assert_almost_equal(
+        (Affine.scale(2, 3) * Affine.rotation(77)).eccentricity,
+        math.sqrt(5) / 3
+    )
+    assert_almost_equal(
+        (Affine.rotation(77) * Affine.scale(2, 3)).eccentricity,
+        math.sqrt(5) / 3
+    )
+    assert_almost_equal(
+        (Affine.translation(32, -47) * Affine.rotation(77) * Affine.scale(2, 3)).eccentricity,
+        math.sqrt(5) / 3
+    )
+
+
+def test_rotation_angle():
+    assert_equal(Affine.identity().rotation_angle, 0.0)
+    assert_equal(Affine.scale(2).rotation_angle, 0.0)
+    assert_equal(Affine.scale(2, 1).rotation_angle, 0.0)
+    assert_almost_equal(Affine.translation(32, -47).rotation_angle, 0.0)
+    assert_almost_equal(Affine.rotation(30).rotation_angle, 30)
+    assert_almost_equal(Affine.rotation(-150).rotation_angle, -150)
+
+
+@raises(UndefinedRotationError)
+def test_rotation_improper():
+    Affine.scale(-1, 1).rotation_angle
+
+
 if __name__ == '__main__':
     unittest.main()
 
